@@ -1,6 +1,7 @@
 from math import degrees
 from itertools import chain, count
 from re import match
+from decimal import Decimal
 from django.utils.safestring import mark_safe
 from numpy import arctan
 
@@ -153,3 +154,27 @@ def canondatecode(datecode, introduced=1960, discontinued=2100):
         year = None
 
     return year
+
+def deg_to_dms(decdegrees):
+    """
+    Convert from decimal degrees to degrees, minutes, seconds.
+    """
+    decdegrees = Decimal(decdegrees)
+    mins, secs = divmod(abs(decdegrees)*3600, 60)
+    degs, mins = divmod(mins, 60)
+    degs, mins = int(degs), int(mins)
+    return degs, mins, secs
+
+
+def gps_ref(direction, angle):
+    """
+    Return the direction of a GPS coordinate
+    """
+    angle=Decimal(angle)
+    if direction == 'latitude':
+        hemi = 'N' if angle>=0 else 'S'
+    elif direction == 'longitude':
+        hemi = 'E' if angle>=0 else 'W'
+    else:
+        hemi = None
+    return hemi
