@@ -15,8 +15,8 @@ def model_name(obj):
 
 @register.filter
 def model_list(obj):
-    return obj._meta.model_name + '-list'
+    return 'schema:' + obj._meta.model_name + '-list'
 
 @register.filter
 def model_add(obj):
-    return obj._meta.model_name + '-create'
\ No newline at end of file
+    return 'schema:' + obj._meta.model_name + '-create'
